@@ -84,9 +84,3 @@ class Ftpsbase(ftplib.FTP_TLS):
                 }
             )
         return files
-
-    def help(self):
-        print(f"=== {type(self).__name__} === \n")
-        print(".get_file(path) => get file from ftp path\n")
-        print(".send_file(path, dest_path) => send file to ftp path\n")
-        print(".list_directory(path) => do ls in ftp in path\n")
